Learn R Programming

fz (version 1.2.0)

fz-package: fz: R Wrapper for the 'funz-fz' Parametric Simulation Framework

Description

Provides R bindings to the 'funz-fz' Python package using 'reticulate'. The 'fz' framework wraps arbitrary simulation codes to run parameter sweeps, design-of-experiments studies, and iterative algorithm-driven analyses by substituting variable placeholders in text input files and collecting outputs into data frames. Calculators can run locally (shell), over SSH, or on 'SLURM' clusters. See https://github.com/Funz/fz for the underlying framework.

Arguments

Author

Maintainer: Yann Richet [email protected] (ORCID)

Authors:

See Also