Provides R bindings to the 'funz-fz' Python package using 'reticulate'. The 'fz' framework wraps arbitrary simulation codes to run parameter sweeps, design-of-experiments studies, and iterative algorithm-driven analyses by substituting variable placeholders in text input files and collecting outputs into data frames. Calculators can run locally (shell), over SSH, or on 'SLURM' clusters. See https://github.com/Funz/fz for the underlying framework.
Maintainer: Yann Richet [email protected] (ORCID)
Authors:
Yann Richet [email protected] (ORCID)
Useful links:
Report bugs at https://github.com/Funz/fz.R/issues